Layout
======

Classes
-------

.. currentmodule:: ansys.edb.core.layout

.. autosummary::
   :toctree: _autosummary

   cell.Cell
   layout.Layout
   mcad_model.McadModel
   voltage_regulator.PowerModule
   voltage_regulator.VoltageRegulator

Enums
-----

.. autosummary::
   :toctree: _autosummary

   cell.CellType
   cell.DesignMode